import { extend } from 'umi-request';
import { history } from 'umi';
import { message } from 'antd';

interface ILoginParams {
  name: string;
  password: string;
}
const request = extend({});

request.interceptors.request.use((url, options) => {
  const token = JSON.parse(localStorage.getItem('user') || '{}')?.token;
  const authHeader = {
    Authorization: `Bearer ${token || ''}`,
    'Content-Type': 'application/json',
    __tenant: '3a0a90fe-9a0d-70f4-200d-a80a41fb6195',
  };
  return {
    url: url,
    options: { ...options, interceptors: true, headers: authHeader },
  };
});

request.interceptors.response.use(async (response): Promise<any> => {
  console.log('response', response);
  if (response.status === 401) {
    localStorage.removeItem('user');
    history.push('/chat');
  } else if (response.status === 200) {
    return response;
  } else {
    message.error('请求失败，请重试! ');
    return Promise.reject(response.statusText);
  }
});

export function loginChatGLM(options: ILoginParams) {
  return request('https://glm-mangement-api.baibaomen.com/api/app/account/login', {
    method: 'POST',
    data: options,
  });
}

export interface IPromptWord {
  type: string;
  content: string;
}
export function GetChatGLMToken(): Promise<string> {
  return request('https://glm-mangement-api.baibaomen.com/user/token', {
    method: 'POST',
  });
}

export function GetPromptList(): Promise<{ items: IPromptWord[] }> {
  return request('https://glm-mangement-api.baibaomen.com/promptwords/page', {
    method: 'POST',
    headers: {
      Authorization: 'Bearer ' + JSON.parse(localStorage.getItem('user') || '')?.token,
      'Content-Type': 'application/json',
    },
    body: JSON.stringify({ pageIndex: 0, pageSize: 10 }),
  });
}

type History = [string, string];
interface ITalkParams {
  prompt: string;
  history: History[];
  max_length?: number;
  top_p?: number;
  temperature?: number;
}

export const CreatedAccount = (params: any): Promise<string> => {
  return request('https://glm-mangement-api.baibaomen.com/User/create', {
    method: 'POST',
    body: JSON.stringify(params),
  });
};

export const getRole = (params?: any): Promise<string> => {
  return request('https://glm-mangement-api.baibaomen.com/User/roles', {
    method: 'POST',
    body: JSON.stringify(params),
  });
};

export const getUserMessage = (params?: any): Promise<string> => {
  return request('https://glm-mangement-api.baibaomen.com/User/page', {
    method: 'POST',
    body: JSON.stringify(params),
  });
};

export const createPromptWords = (params: any): Promise<any> => {
  return request('https://glm-mangement-api.baibaomen.com/PromptWords/create', {
    method: 'POST',
    data: params
  })
}

export const updatePromptWords = (params: any): Promise<any> => {
  return request('https://glm-mangement-api.baibaomen.com/PromptWords/update', {
    method: 'POST',
    data: params
  })
}

export const deletePromptWords = (params: any): Promise<any> => {
  return request('https://glm-mangement-api.baibaomen.com/PromptWords/delete', {
    method: 'POST',
    data: params
  })
}

export const pagePromptWords = (params: any): Promise<any> => {
  return request('https://glm-mangement-api.baibaomen.com/PromptWords/page', {
    method: 'POST',
    data: params
  })
}

export const typePromptWords = (): Promise<any> => {
  return request('https://glm-mangement-api.baibaomen.com/PromptWords/type', {
    method: 'POST',
  })
}

export const postDeleteUser = (params?: any): Promise<string> => {
  return request('https://glm-mangement-api.baibaomen.com/User/delete', {
    method: 'POST',
    data: params,
  });
};

export const postResetUser = (params?: any): Promise<string> => {
  return request('https://glm-mangement-api.baibaomen.com/User/reset', {
    method: 'POST',
    body: JSON.stringify(params),
  });
};

export const postEditUser = (params?: any): Promise<string> => {
  return request('https://glm-mangement-api.baibaomen.com/User/update', {
    method: 'POST',
    body: JSON.stringify(params),
  });
};
